# -*- encoding: utf-8 -*-

from django.db import models
from managers import NoDeleteManager, ActifsManager, InactifsManager


class AUFMetadata(models.Model):
    """
    Méta-données AUF.
    supprime = niveau système
    actif = niveau utilisateur
    """
    supprime = models.BooleanField(default=False)
    date_creation = models.DateTimeField(null=True, blank=True, verbose_name=u"Date de création",)
    user_creation = models.ForeignKey('auth.User', verbose_name=u"Crée par",
                            db_column='user_creation', related_name='+',
                            null=True, blank=True)
    date_modification = models.DateTimeField(null=True, blank=True, verbose_name=u"Date de modification",)
    user_modification = models.ForeignKey('auth.User', verbose_name=u"Modifié par",
                            db_column='user_modification', related_name='+',
                            null=True, blank=True)
    actif = models.BooleanField(default=True)
    date_activation = models.DateTimeField(null=True, blank=True, verbose_name=u"Date d'activation",)
    user_activation = models.ForeignKey('auth.User',  verbose_name=u"Activé par",
                            db_column='user_activation', related_name='+',
                            null=True, blank=True)
    date_desactivation = models.DateTimeField(null=True, blank=True, verbose_name=u"Date de désactivation",)
    user_desactivation = models.ForeignKey('auth.User', verbose_name=u"Désactivé par", 
                            db_column='user_desactivation', related_name='+',
                            null=True, blank=True)

    objects = NoDeleteManager()
    actifs = ActifsManager()
    inactifs = InactifsManager()

    class Meta:
        abstract = True

    def delete(self):
        self.supprime = True
        self.save()


